package logic

import (
	"fusenapi/utils/basic"
	"net/http"
	"strings"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type DeleteLdapOrganizationLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewDeleteLdapOrganizationLogic(ctx context.Context, svcCtx *svc.ServiceContext) *DeleteLdapOrganizationLogic {
	return &DeleteLdapOrganizationLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *DeleteLdapOrganizationLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *DeleteLdapOrganizationLogic) DeleteLdapOrganization(req *types.DeleteLdapOrganizationReq, r *http.Request) (resp *basic.Response) {

	if !l.svcCtx.Ldap.VerifyAuthority(r) {
		return resp.SetStatusWithMessage(basic.CodeUnAuth, "无权限，请联系管理员开通")
	}
	req.OrganizationDN = strings.Trim(req.OrganizationDN, " ")
	if len(req.OrganizationDN) <= 3 || req.OrganizationDN[:3] != "ou=" {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, "参数错误，无效的组织DN")
	}
	if err := l.svcCtx.Ldap.Delete(req.OrganizationDN); err != nil {
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeServiceErr, "删除ldap组织失败,"+err.Error())
	}
	return resp.SetStatusWithMessage(basic.CodeOK, "删除成功")
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *DeleteLdapOrganizationLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
